@@ -5,6 +5,7 @@ import (
 	"os"
 	"os/exec"
 	"path"
+	"runtime"
 	"strconv"
 	"strings"
 	"testing"
@@ -214,8 +215,8 @@ func TestGetLongLine(t *testing.T) {
 	assert.Equal(t, len(lines.Lines), 1)
 
 	line := lines.Lines[0]
-	assert.Assert(t, strings.HasPrefix(line.Plain(), "1 2 3 4"), "<%s>", line)
-	assert.Assert(t, strings.HasSuffix(line.Plain(), "0123456789"), line)
+	assert.Assert(t, strings.HasPrefix(line.Plain(), "1 2 3 4"), "<%s>", line.Plain())
+	assert.Assert(t, strings.HasSuffix(line.Plain(), "0123456789"), line.Plain())
 
 	assert.Equal(t, len(line.Plain()), 100021)
 }
@@ -253,7 +254,8 @@ func TestStatusText(t *testing.T) {
 	if line.Lines != nil {
 		t.Error("line.lines is should have been nil when reading from an empty stream")
 	}
-	assert.Equal(t, line.StatusText, "empty: <empty>")
+	assert.Equal(t, line.FilenameText, "empty")
+	assert.Equal(t, line.StatusText, ": <empty>")
 }
 
 func testCompressedFile(t *testing.T, filename string) {
@@ -309,6 +311,38 @@ func TestReadStreamDoneYesHighlighting(t *testing.T) {
 	assert.NilError(t, testMe.Wait())
 }
 
+func TestReadFromDevFd(t *testing.T) {
+	if runtime.GOOS == "windows" {
+		t.Skip("/dev/fd is not available on Windows")
+
+		return
+	}
+
+	readPipe, writePipe, err := os.Pipe()
+	assert.NilError(t, err)
+	defer readPipe.Close() //nolint:errcheck
+
+	_, err = writePipe.WriteString("test\n")
+	assert.NilError(t, err)
+	assert.NilError(t, writePipe.Close())
+
+	fileName := "/dev/fd/" + strconv.Itoa(int(readPipe.Fd()))
+	testMe, err := NewFromFilename(fileName, formatters.TTY, ReaderOptions{Style: styles.Get("native")})
+	assert.NilError(t, err)
+	assert.NilError(t, testMe.Wait())
+
+	lines := testMe.GetLines(linemetadata.Index{}, 10)
+	assert.Equal(t, len(lines.Lines), 1)
+	assert.Equal(t, lines.Lines[0].Plain(), "test")
+}
+
+func TestTryOpenDirectory(t *testing.T) {
+	tempDir := t.TempDir()
+
+	err := TryOpen(tempDir)
+	assert.Assert(t, err != nil, "TryOpen should fail on directories")
+}
+
 func TestReadTextDone(t *testing.T) {
 	testMe := NewFromTextForTesting("", "Johan")
 
@@ -550,7 +584,7 @@ func TestReadUpdatingFile_HalfUtf8(t *testing.T) {
 	assert.NilError(t, err)
 
 	// Give the reader some time to react
-	for i := 0; i < 20; i++ {
+	for range 20 {
 		allLines := testMe.GetLines(linemetadata.Index{}, 10)
 		if len(allLines.Lines) == 2 {
 			break
@@ -652,6 +686,9 @@ func BenchmarkReadLargeFile(b *testing.B) {
 
 	b.SetBytes(int64(totalBytesWritten))
 
+	// Try making the whole run more predictable
+	runtime.GC()
+
 	b.ResetTimer()
 	for n := 0; n < b.N; n++ {
 		readMe, err := NewFromFilename(
@@ -663,6 +700,7 @@ func BenchmarkReadLargeFile(b *testing.B) {
 			})
 		assert.NilError(b, err)
 
+		<-readMe.MaybeDone
 		assert.NilError(b, readMe.Wait())
 		assert.NilError(b, readMe.Err)
 	}
